@@ -1,6 +1,6 @@
 import requests
 from datetime import datetime
-from const import *
+from switchbee.const import *
 import urllib3
 
 class SwitchBee():
